@@ -19,8 +19,6 @@
 
 // based on code (c) FFMpeg team
 
-
-
 typedef uint8_t lives_asf_guid[16];
 
 const lives_asf_guid lives_asf_header = {
@@ -135,7 +133,6 @@ const lives_asf_guid lives_asf_digital_signature = {
   0xfc, 0xb3, 0x11, 0x22, 0x23, 0xbd, 0xd2, 0x11, 0xb4, 0xb7, 0x00, 0xa0, 0xc9, 0x55, 0xfc, 0x6e
 };
 
-
 static const lives_asf_guid index_guid = {
   0x90, 0x08, 0x00, 0x33, 0xb1, 0xe5, 0xcf, 0x11, 0x89, 0xf4, 0x00, 0xa0, 0xc9, 0x03, 0x49, 0xcb
 };
@@ -144,10 +141,6 @@ static const lives_asf_guid stream_bitrate_guid = { /* (http://get.to/sdp) */
   0xce, 0x75, 0xf8, 0x7b, 0x8d, 0x46, 0xd1, 0x11, 0x8d, 0x82, 0x00, 0x60, 0x97, 0xc9, 0xa2, 0xb2
 };
 
-
-
-
-
 /* List of official tags at http://msdn.microsoft.com/en-us/library/dd743066(VS.85).aspx */
 /*const AVMetadataConv lives_asf_metadata_conv[] = {
   { "WM/AlbumArtist"     , "album_artist"},
@@ -169,11 +162,8 @@ static const lives_asf_guid stream_bitrate_guid = { /* (http://get.to/sdp) */
   { 0 }
   };*/
 
-
-
 #define ASF_PROBE_SIZE 16
 
-
 #define PACKET_SIZE 3200
 
 typedef struct {
@@ -195,10 +185,8 @@ typedef struct {
 
   int      palette_changed;
   uint32_t palette[256];
-
 } ASFStream;
 
-
 typedef struct {
   lives_asf_guid guid;                  ///< generated by client computer
   uint64_t file_size;         /**< in bytes
@@ -224,13 +212,11 @@ typedef struct {
 			       *   individual media streams */
 } ASFMainHeader;
 
-
 typedef struct {
   uint32_t packet_number;
   uint16_t packet_count;
 } ASFIndex;
 
-
 typedef struct {
   uint32_t seqno;
   int is_streamed;
@@ -277,7 +263,6 @@ typedef struct {
 
   int stream_index;
 
-
   int64_t last_indexed_pts;
   ASFIndex *index_ptr;
   uint32_t nb_index_count;
@@ -287,7 +272,6 @@ typedef struct {
   ASFStream *asf_st;                   ///< currently decoded stream
 } ASFContext;
 
-
 #define FRAME_HEADER_SIZE 17
 
 typedef struct _index_entry index_entry;
@@ -299,7 +283,6 @@ struct _index_entry {
   uint8_t frag; ///< fragment number (counting only video fragments)
 };
 
-
 typedef struct {
   index_entry *idx;  ///< linked list of index (keyframes)
 
@@ -308,8 +291,6 @@ typedef struct {
   pthread_mutex_t mutex;
 } index_container_t;
 
-
-
 typedef struct {
   int fd; ///< file handle 208 477373 22415 108fat32
   int64_t input_position; /// current or next input postion
@@ -335,7 +316,7 @@ typedef struct {
   int fragnum; ///< current fragment number
 } lives_asf_priv_t;
 
-
+#ifndef GET_UTF16
 #define GET_UTF16(val, GET_16BIT, ERROR)	\
   val = GET_16BIT;				\
   {						\
@@ -344,11 +325,12 @@ typedef struct {
       val = GET_16BIT - 0xDC00;			\
       if (val > 0x3FFU || hi > 0x3FFU)		\
 	ERROR					\
-	  val += (hi<<10) + 0x10000;		\
+	  val += (hi << 10) + 0x10000;		\
     }						\
-  }						\
-
+  }
+#endif
 
+#ifndef PUT_UTF8
 #define PUT_UTF8(val, tmp, PUT_BYTE)			\
   {							\
     int bytes, shift;					\
@@ -368,19 +350,19 @@ typedef struct {
             }						\
     }							\
   }
+#endif
 
-
+#ifndef DO_2BITS
 #define DO_2BITS(bits, var, defval)					\
   switch (bits & 3)							\
     {									\
-      int dummy=0;							\
-    case 3: dummy=read(priv->fd,buffer,4); var = get_le32int(buffer); priv->input_position+=4; rsize+=4; break; \
-    case 2: dummy=read (priv->fd,buffer,2); var = get_le16int(buffer); priv->input_position+=2; rsize+=2; break; \
-    case 1: dummy=read (priv->fd,buffer,1); var = *buffer; priv->input_position++; rsize++; break; \
-    default: var = defval; dummy=dummy; break;				\
+      int dummy = 0;							\
+    case 3: dummy = read(priv->fd, buffer, 4); var = get_le32int(buffer); priv->input_position += 4; rsize += 4; break; \
+    case 2: dummy = read(priv->fd, buffer, 2); var = get_le16int(buffer); priv->input_position += 2; rsize += 2; break; \
+    case 1: dummy = read(priv->fd, buffer, 1); var = *buffer; priv->input_position++; rsize++; break; \
+    default: var = defval; dummy = dummy; break;				\
     }
-
-
+#endif
 
 index_entry *index_upto(const lives_clip_data_t *, int pts);
 
