@@ -28,8 +28,8 @@
 
 // system header flags
 enum {
-    FLV_HEADER_FLAG_HASVIDEO = 1,
-    FLV_HEADER_FLAG_HASAUDIO = 4,
+  FLV_HEADER_FLAG_HASVIDEO = 1,
+  FLV_HEADER_FLAG_HASAUDIO = 4,
 };
 
 // packet flag masks
@@ -44,39 +44,39 @@ enum {
 
 // amf data types for metadata
 typedef enum {
-    AMF_DATA_TYPE_NUMBER      = 0x00,
-    AMF_DATA_TYPE_BOOL        = 0x01,
-    AMF_DATA_TYPE_STRING      = 0x02,
-    AMF_DATA_TYPE_OBJECT      = 0x03,
-    AMF_DATA_TYPE_NULL        = 0x05,
-    AMF_DATA_TYPE_UNDEFINED   = 0x06,
-    AMF_DATA_TYPE_REFERENCE   = 0x07,
-    AMF_DATA_TYPE_MIXEDARRAY  = 0x08,
-    AMF_DATA_TYPE_OBJECT_END  = 0x09,
-    AMF_DATA_TYPE_ARRAY       = 0x0a,
-    AMF_DATA_TYPE_DATE        = 0x0b,
-    AMF_DATA_TYPE_LONG_STRING = 0x0c,
-    AMF_DATA_TYPE_UNSUPPORTED = 0x0d,
+  AMF_DATA_TYPE_NUMBER      = 0x00,
+  AMF_DATA_TYPE_BOOL        = 0x01,
+  AMF_DATA_TYPE_STRING      = 0x02,
+  AMF_DATA_TYPE_OBJECT      = 0x03,
+  AMF_DATA_TYPE_NULL        = 0x05,
+  AMF_DATA_TYPE_UNDEFINED   = 0x06,
+  AMF_DATA_TYPE_REFERENCE   = 0x07,
+  AMF_DATA_TYPE_MIXEDARRAY  = 0x08,
+  AMF_DATA_TYPE_OBJECT_END  = 0x09,
+  AMF_DATA_TYPE_ARRAY       = 0x0a,
+  AMF_DATA_TYPE_DATE        = 0x0b,
+  AMF_DATA_TYPE_LONG_STRING = 0x0c,
+  AMF_DATA_TYPE_UNSUPPORTED = 0x0d,
 } AMFDataType;
 
 
 // video codecs
 enum {
-    FLV_CODECID_H263    = 2,
-    FLV_CODECID_SCREEN  = 3,
-    FLV_CODECID_VP6     = 4,
-    FLV_CODECID_VP6A    = 5,
-    FLV_CODECID_SCREEN2 = 6,
-    FLV_CODECID_H264    = 7,
+  FLV_CODECID_H263    = 2,
+  FLV_CODECID_SCREEN  = 3,
+  FLV_CODECID_VP6     = 4,
+  FLV_CODECID_VP6A    = 5,
+  FLV_CODECID_SCREEN2 = 6,
+  FLV_CODECID_H264    = 7,
 };
 
 
 // packet tags
 enum {
-    FLV_TAG_TYPE_ERROR = 0x00,
-    FLV_TAG_TYPE_AUDIO = 0x08,
-    FLV_TAG_TYPE_VIDEO = 0x09,
-    FLV_TAG_TYPE_META  = 0x12,
+  FLV_TAG_TYPE_ERROR = 0x00,
+  FLV_TAG_TYPE_AUDIO = 0x08,
+  FLV_TAG_TYPE_VIDEO = 0x09,
+  FLV_TAG_TYPE_META  = 0x12,
 };
 
 
@@ -110,10 +110,22 @@ struct _index_entry {
 };
 
 
+typedef struct {
+  index_entry *idxhh;  ///< head of head list
+  index_entry *idxht; ///< tail of head list
+  index_entry *idxth; ///< head of tail list
+
+  int nclients;
+  lives_clip_data_t **clients;
+  pthread_mutex_t mutex;
+} index_container_t;
+
+
 
 typedef struct {
   int fd;
   int pack_offset;
+  boolean inited;
   int64_t input_position;
   int64_t data_start;
   AVCodec *codec;
@@ -121,9 +133,7 @@ typedef struct {
   AVFrame *picture;
   AVPacket avpkt;
   int64_t last_frame; ///< last frame displayed
-  index_entry *idxhh;  ///< head of head list (always first frame)
-  index_entry *idxht; ///< tail of head list
-  index_entry *idxth; ///< head of tail list
+  index_container_t *idxc;
 } lives_flv_priv_t;
 
 index_entry *index_upto(const lives_clip_data_t *, int pts);
