@@ -12,7 +12,6 @@
 
 // TODO - user defined screen mapping areas
 
-
 #include "main.h"
 #include "effects-weed.h"
 #include "effects.h"
@@ -60,9 +59,9 @@ void ce_thumbs_set_interactive(boolean interactive) {
       }
     }
   }
-
 }
 
+
 #if LIVES_HAS_GRID_WIDGET
 static boolean switch_clip_cb(LiVESWidget *eventbox, LiVESXEventButton *event, livespointer user_data) {
   int i = LIVES_POINTER_TO_INT(user_data);
@@ -72,6 +71,7 @@ static boolean switch_clip_cb(LiVESWidget *eventbox, LiVESXEventButton *event, l
   return FALSE;
 }
 
+
 static void ce_thumbs_fx_changed(LiVESCombo *combo, livespointer user_data) {
   // callback after user switches fx via combo
   int key = LIVES_POINTER_TO_INT(user_data);
@@ -228,7 +228,6 @@ void start_ce_thumb_mode(void) {
   }
 
   for (i = 0; i < rte_keys_virtual; i++) {
-
     pscrolls[i] = NULL;
 
     fxlist = NULL;
@@ -251,7 +250,6 @@ void start_ce_thumb_mode(void) {
     ch_fns[i] = lives_signal_connect_after(LIVES_GUI_OBJECT(key_checks[i]), LIVES_WIDGET_TOGGLED_SIGNAL,
                                            LIVES_GUI_CALLBACK(rte_on_off_callback_hook), LIVES_INT_TO_POINTER(i + 1));
 
-
     fxcombos[i] = lives_standard_combo_new(NULL, FALSE, fxlist, LIVES_BOX(hbox), NULL);
 
     if (fxlist != NULL) {
@@ -288,7 +286,6 @@ void start_ce_thumb_mode(void) {
   hbox = lives_hbox_new(FALSE, 0);
   lives_widget_set_hexpand(hbox, FALSE);
 
-
   lives_box_pack_start(LIVES_BOX(vbox3), hbox, FALSE, TRUE, 0);
   arrow = lives_arrow_new(LIVES_ARROW_LEFT, LIVES_SHADOW_NONE);
   lives_box_pack_start(LIVES_BOX(hbox), arrow, FALSE, TRUE, 0);
@@ -302,9 +299,6 @@ void start_ce_thumb_mode(void) {
   arrow = lives_arrow_new(LIVES_ARROW_RIGHT, LIVES_SHADOW_NONE);
   lives_box_pack_start(LIVES_BOX(hbox), arrow, FALSE, TRUE, 0);
 
-
-
-
   // screen areas
   vbox = lives_vbox_new(FALSE, widget_opts.packing_height);
   tscroll = lives_standard_scrolled_window_new(width, height, vbox);
@@ -313,16 +307,14 @@ void start_ce_thumb_mode(void) {
   lives_scrolled_window_set_policy(LIVES_SCROLLED_WINDOW(tscroll), LIVES_POLICY_NEVER, LIVES_POLICY_AUTOMATIC);
   lives_widget_set_hexpand(tscroll, FALSE);
 
-
   for (i = 0; i < n_screen_areas; i++) {
     hbox = lives_hbox_new(FALSE, 0);
     lives_box_pack_start(LIVES_BOX(vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
     // radiobuttons for fx
-    rb_fx_areas[i] = lives_standard_radio_button_new("", FALSE, rb_fx_areas_group, LIVES_BOX(hbox),
+    rb_fx_areas[i] = lives_standard_radio_button_new("", FALSE, &rb_fx_areas_group, LIVES_BOX(hbox),
                      (tmp = lives_strdup_printf(_("Show / apply effects to %s\n"),
                             mainw->screen_areas[i].name)));
-    rb_fx_areas_group = lives_radio_button_get_group(LIVES_RADIO_BUTTON(rb_fx_areas[i]));
     lives_free(tmp);
 
     if (i != SCREEN_AREA_FOREGROUND) lives_widget_set_sensitive(rb_fx_areas[i], FALSE);
@@ -331,10 +323,10 @@ void start_ce_thumb_mode(void) {
     lives_box_pack_start(LIVES_BOX(hbox), label, FALSE, TRUE, 0);
 
     // radiobuttons for fx
-    rb_clip_areas[i] = lives_standard_radio_button_new("", FALSE, rb_clip_areas_group, LIVES_BOX(hbox),
+    rb_clip_areas[i] = lives_standard_radio_button_new("", FALSE,
+                       &rb_clip_areas_group, LIVES_BOX(hbox),
                        (tmp = lives_strdup_printf(_("Select clip for %s\n"),
                               mainw->screen_areas[i].name)));
-    rb_clip_areas_group = lives_radio_button_get_group(LIVES_RADIO_BUTTON(rb_clip_areas[i]));
     lives_free(tmp);
 
     rb_clip_fns[i] = lives_signal_connect(LIVES_GUI_OBJECT(rb_clip_areas[i]), LIVES_WIDGET_TOGGLED_SIGNAL,
@@ -366,7 +358,6 @@ void start_ce_thumb_mode(void) {
 
   lives_widget_context_update(); // need size of cscroll to fit thumbs
 
-
   cpw = (lives_widget_get_allocation_width(tscroll) - widget_opts.border_width * 2) / (width * 1.5) - 2;
 
   // add thumbs to grid
@@ -470,8 +461,6 @@ void end_ce_thumb_mode(void) {
 }
 
 
-
-
 void ce_thumbs_add_param_box(int key, boolean remove) {
   // when an effect with params is applied, show the parms in a box
   weed_plant_t *inst, *ninst;
@@ -506,7 +495,6 @@ void ce_thumbs_add_param_box(int key, boolean remove) {
   } while (weed_plant_has_leaf(ninst, WEED_LEAF_HOST_NEXT_INSTANCE) &&
            (ninst = weed_get_plantptr_value(ninst, WEED_LEAF_HOST_NEXT_INSTANCE, &error)) != NULL);
 
-
   // here we just check if we have any params to display
   if (!make_param_box(NULL, rfx)) {
     rfx_free(rfx);
@@ -514,7 +502,6 @@ void ce_thumbs_add_param_box(int key, boolean remove) {
     return;
   }
 
-
   vbox = lives_vbox_new(FALSE, 0);
 
   pscrolls[key] = lives_standard_scrolled_window_new(-1, -1, vbox);
@@ -543,7 +530,6 @@ void ce_thumbs_add_param_box(int key, boolean remove) {
   lives_signal_connect_after(LIVES_GUI_OBJECT(pin_check), LIVES_WIDGET_TOGGLED_SIGNAL,
                              LIVES_GUI_CALLBACK(pin_toggled), LIVES_INT_TO_POINTER(key));
 
-
   on_fx_pre_activate(rfx, 1, vbox);
 
   // record the key so we know whose parameters to record later
@@ -582,7 +568,6 @@ static void ce_thumbs_remove_param_boxes(boolean remove_pinned) {
 }
 
 
-
 void ce_thumbs_register_rfx_change(int key, int mode) {
   // register a param box to be updated visually, from an asynchronous source - either from a A->V data connection or from osc
   if (key >= rte_keys_virtual || pscrolls[key] == NULL) return;
@@ -667,7 +652,6 @@ void ce_thumbs_reset_combo(int key) {
     lives_widget_set_sensitive(key_checks[key], FALSE);
     lives_combo_set_active_string(LIVES_COMBO(fxcombos[key]), "");
   }
-
 }
 
 
@@ -731,7 +715,6 @@ void ce_thumbs_highlight_current_clip(void) {
     }
     lives_widget_set_state(clip_boxes[i], LIVES_WIDGET_STATE_NORMAL);
   }
-
 }
 
 
