@@ -55,7 +55,7 @@
 #define V_RESIZE_ADJUST ((W_PACKING_WIDTH+2)*3)
 #define H_RESIZE_ADJUST ((W_PACKING_HEIGHT+2)*2)
 
-#if GTK_CHECK_VERSION(3,0,0)
+#if GTK_CHECK_VERSION(3, 0, 0)
 #define CE_FRAME_HSPACE ((int)(320.*widget_opts.scale))
 #else
 #define CE_FRAME_HSPACE ((int)(420.*widget_opts.scale))
@@ -124,7 +124,7 @@
 #define MAX_MSG_WIDTH_CHARS ((int)(100.*widget_opts.scale)) ///< max width of text on warning/error labels
 
 /// size of the fx dialog windows scrollwindow
-#define RFX_WINSIZE_H ((int)(mainw->scr_width>=1024?(820.*widget_opts.scale):640))
+#define RFX_WINSIZE_H ((int)(mainw->scr_width >= 1024 ? (820.*widget_opts.scale) : 640))
 #define RFX_WINSIZE_V ((int)(480.*widget_opts.scale))
 
 #define DEF_BUTTON_WIDTH ((int)(80.*widget_opts.scale))
@@ -132,6 +132,7 @@
 #define DEF_DIALOG_WIDTH RFX_WINSIZE_H
 #define DEF_DIALOG_HEIGHT RFX_WINSIZE_V
 
+#define LIVES_MAIN_WINDOW_WIDGET (mainw->multitrack == NULL ? mainw->LiVES : mainw->multitrack->window)
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -160,15 +161,15 @@
 
 /// external control types
 typedef enum {
-  EXT_CNTL_NONE=-1, ///< not used
-  EXT_CNTL_JS=0,
-  EXT_CNTL_MIDI=1
+  EXT_CNTL_NONE = -1, ///< not used
+  EXT_CNTL_JS = 0,
+  EXT_CNTL_MIDI = 1
 } lives_ext_cntl_t;
 
 
 /// timebase sources
 typedef enum {
-  LIVES_TIME_SOURCE_NONE=0,
+  LIVES_TIME_SOURCE_NONE = 0,
   LIVES_TIME_SOURCE_SYSTEM,
   LIVES_TIME_SOURCE_SOUNDCARD,
   LIVES_TIME_SOURCE_EXTERNAL
@@ -177,7 +178,7 @@ typedef enum {
 
 
 typedef enum {
-  LIVES_TOY_NONE=0,
+  LIVES_TOY_NONE = 0,
   LIVES_TOY_MAD_FRAMES,
   LIVES_TOY_TV,
   LIVES_TOY_AUTOLIVES
@@ -197,7 +198,7 @@ typedef enum {
 
 /// various return conditions from rendering (multitrack or after recording)
 typedef enum {
-  LIVES_RENDER_ERROR_NONE=0,
+  LIVES_RENDER_ERROR_NONE = 0,
   LIVES_RENDER_READY,
   LIVES_RENDER_PROCESSING,
   LIVES_RENDER_EFFECTS_PAUSED,
@@ -213,7 +214,7 @@ typedef enum {
 
 /// disk/storage status values
 typedef enum {
-  LIVES_STORAGE_STATUS_UNKNOWN=0,
+  LIVES_STORAGE_STATUS_UNKNOWN = 0,
   LIVES_STORAGE_STATUS_NORMAL,
   LIVES_STORAGE_STATUS_WARNING,
   LIVES_STORAGE_STATUS_CRITICAL,
@@ -226,7 +227,7 @@ typedef enum {
 #define DVD_AUDIO_CHAN_MAX 159
 
 enum {
-  LIVES_DEVICE_CD=0,
+  LIVES_DEVICE_CD = 0,
   LIVES_DEVICE_DVD, // 1
   LIVES_DEVICE_VCD, // 2
   LIVES_DEVICE_INTERNAL, // 2
@@ -309,8 +310,6 @@ typedef struct {
 
   lives_colRGBA64_t ce_sel;
   lives_colRGBA64_t ce_unsel;
-
-
 } _palette;
 
 /// screen details
@@ -326,7 +325,7 @@ typedef struct {
 
 /// constant strings
 enum {
-  LIVES_STRING_CONSTANT_ANY=0,
+  LIVES_STRING_CONSTANT_ANY = 0,
   LIVES_STRING_CONSTANT_NONE,
   LIVES_STRING_CONSTANT_RECOMMENDED,
   LIVES_STRING_CONSTANT_DISABLED,
@@ -367,8 +366,9 @@ enum {
 
 // filters
 
-#define LIVES_SUBS_FILTER  {"*.srt","*.sub",NULL}
-#define LIVES_AUDIO_LOAD_FILTER  {"*.it","*.mp3","*.wav","*.ogg","*.mod","*.xm","*.wma","*.flac",NULL}
+#define LIVES_SUBS_FILTER  {"*.srt", "*.sub", NULL}
+#define LIVES_AUDIO_LOAD_FILTER  {"*.it", "*.mp3", "*.wav", "*.ogg", "*.mod", "*.xm", "*.wma", "*.flac", NULL}
+#define LIVES_TV_CARD_TYPES  {"v4l2", "v4l", "bsdbt848", "dummy", "*autodetect", "yv12", "*", "rgb32", "rgb24", "rgb16", "rgb15", "uyvy", "yuy2", "i2420", NULL}
 
 
 typedef struct {
@@ -396,7 +396,7 @@ typedef struct {
   // files
   int current_file;
   int first_free_file;
-  lives_clip_t *files[MAX_FILES+1]; ///< +1 for the clipboard
+  lives_clip_t *files[MAX_FILES + 1]; ///< +1 for the clipboard
   char vid_load_dir[PATH_MAX];
   char vid_save_dir[PATH_MAX];
   char vid_dl_dir[PATH_MAX];
@@ -498,7 +498,7 @@ typedef struct {
 
 
 #ifdef GUI_GTK
-#if GTK_CHECK_VERSION(3,0,0)
+#if GTK_CHECK_VERSION(3, 0, 0)
   Window foreign_id;
 #else
   GdkNativeWindow foreign_id;
@@ -730,7 +730,7 @@ typedef struct {
   boolean hrule_blocked;
 
   /// stored clips
-  int clipstore[FN_KEYS-1];
+  int clipstore[FN_KEYS - 1];
 
   /// key function for autorepeat ctrl-arrows
   uint32_t ksnoop;
@@ -1327,9 +1327,7 @@ typedef struct {
   char sepimg_path[PATH_MAX];
 
   uint64_t aud_data_written;
-
   ////////////////////
-
 } mainwindow;
 
 extern _palette *palette;
@@ -1349,7 +1347,6 @@ typedef struct {
 
   int *list_to_rfx_index;
   LiVESList *trans_list;
-
 } _merge_opts;
 
 extern _merge_opts *merge_opts;
