@@ -83,24 +83,24 @@ typedef enum {
 typedef enum {
   // undo actions
   /// no event_list
-  MT_UNDO_NONE=0,
-  MT_UNDO_INSERT_BLOCK=1,
-  MT_UNDO_INSERT_AUDIO_BLOCK=2,
+  MT_UNDO_NONE = 0,
+  MT_UNDO_INSERT_BLOCK = 1,
+  MT_UNDO_INSERT_AUDIO_BLOCK = 2,
 
   // minimal event_list
-  MT_UNDO_APPLY_FILTER=512,
-  MT_UNDO_DELETE_FILTER=513,
-  MT_UNDO_SPLIT=514,
-  MT_UNDO_SPLIT_MULTI=515,
-  MT_UNDO_FILTER_MAP_CHANGE=516,
+  MT_UNDO_APPLY_FILTER = 512,
+  MT_UNDO_DELETE_FILTER = 513,
+  MT_UNDO_SPLIT = 514,
+  MT_UNDO_SPLIT_MULTI = 515,
+  MT_UNDO_FILTER_MAP_CHANGE = 516,
 
   // full backups of event_list
-  MT_UNDO_DELETE_BLOCK=1024,
-  MT_UNDO_MOVE_BLOCK=1025,
-  MT_UNDO_REMOVE_GAPS=1026,
-  MT_UNDO_DELETE_AUDIO_BLOCK=1027,
-  MT_UNDO_MOVE_AUDIO_BLOCK=1028,
-  MT_UNDO_INSERT_GAP=1029
+  MT_UNDO_DELETE_BLOCK = 1024,
+  MT_UNDO_MOVE_BLOCK = 1025,
+  MT_UNDO_REMOVE_GAPS = 1026,
+  MT_UNDO_DELETE_AUDIO_BLOCK = 1027,
+  MT_UNDO_MOVE_AUDIO_BLOCK = 1028,
+  MT_UNDO_INSERT_GAP = 1029
 } lives_mt_undo_t;
 
 
@@ -116,7 +116,7 @@ typedef enum {
 
 
 typedef enum {
-  POLY_NONE=0,
+  POLY_NONE = 0,
   POLY_CLIPS,
   POLY_IN_OUT,
   POLY_FX_STACK,
@@ -135,14 +135,14 @@ typedef enum {
 
 
 typedef enum {
-  MT_LAST_FX_NONE=0,
+  MT_LAST_FX_NONE = 0,
   MT_LAST_FX_BLOCK,
   MT_LAST_FX_REGION
 } lives_mt_last_fx_type_t;
 
 
 typedef enum {
-  FX_ORD_NONE=0,
+  FX_ORD_NONE = 0,
   FX_ORD_BEFORE,
   FX_ORD_AFTER
 } lives_mt_fx_order_t;
@@ -150,7 +150,7 @@ typedef enum {
 
 typedef enum {
   // block state
-  BLOCK_UNSELECTED=0,
+  BLOCK_UNSELECTED = 0,
   BLOCK_SELECTED
 } lives_mt_block_state_t;
 
@@ -650,7 +650,6 @@ struct _mt {
 
   char *force_load_name; ///< pointer to a string which contains a filename to be force loaded when load_event_list_activate() is called.
   ///< Normally NULL except when called from language bindings.
-
 };  // lives_mt
 
 
@@ -700,7 +699,6 @@ struct _track_rect {
 
   LiVESWidget
   *eventbox; ///< pointer to eventbox widget which contains this block; we can use its "layer_number" to get the track/layer number
-
 };
 
 
@@ -775,6 +773,7 @@ void mt_set_autotrans(int idx);
 weed_plant_t *add_blank_frames_up_to(weed_plant_t *event_list, weed_plant_t *start_event, weed_timecode_t end_tc, double fps);
 
 // track functions
+char *get_track_name(lives_mt *, int track_num, boolean is_audio);
 void on_cback_audio_activate(LiVESMenuItem *, livespointer mt);
 LiVESWidget *add_audio_track(lives_mt *, int trackno, boolean behind);
 int add_video_track_behind(LiVESMenuItem *, livespointer mt);
@@ -792,7 +791,6 @@ boolean track_arrow_pressed(LiVESWidget *ahbox, LiVESXEventButton *, livespointe
 void track_select(lives_mt *);  ///< must call after setting mt->current_track
 boolean mt_track_is_audio(lives_mt *, int ntrack); ///< return TRUE if ntrack is a valid backing audio track
 boolean mt_track_is_video(lives_mt *, int ntrack); ///< return TRUE if ntrack is a valid video track
-char *get_track_name(lives_mt *mt, int track_num, boolean is_audio);
 
 void mt_do_autotransition(lives_mt *, track_rect *block); ///< call this on a block to apply autotransition on it
 
@@ -845,7 +843,6 @@ int get_clip_for_block(track_rect *block);
 
 // timeline functions
 boolean resize_timeline(lives_mt *);
-void mt_tl_move_relative(lives_mt *, double pos_rel);
 void mt_tl_move(lives_mt *, double pos_abs);
 void set_timeline_end_secs(lives_mt *, double secs);
 boolean on_timeline_press(LiVESWidget *, LiVESXEventButton *, livespointer mt);
@@ -987,19 +984,19 @@ boolean mt_nextclip(LiVESAccelGroup *, LiVESObject *, uint32_t keyval, LiVESXMod
 
 typedef enum {
   /* default to warn about */
-  LMAP_ERROR_MISSING_CLIP=1,
-  LMAP_ERROR_CLOSE_FILE=2,
-  LMAP_ERROR_DELETE_FRAMES=3,
-  LMAP_ERROR_DELETE_AUDIO=4,
+  LMAP_ERROR_MISSING_CLIP = 1,
+  LMAP_ERROR_CLOSE_FILE = 2,
+  LMAP_ERROR_DELETE_FRAMES = 3,
+  LMAP_ERROR_DELETE_AUDIO = 4,
 
   /*non-default*/
-  LMAP_ERROR_SHIFT_FRAMES=65,
-  LMAP_ERROR_ALTER_FRAMES=66,
-  LMAP_ERROR_SHIFT_AUDIO=67,
-  LMAP_ERROR_ALTER_AUDIO=68,
+  LMAP_ERROR_SHIFT_FRAMES = 65,
+  LMAP_ERROR_ALTER_FRAMES = 66,
+  LMAP_ERROR_SHIFT_AUDIO = 67,
+  LMAP_ERROR_ALTER_AUDIO = 68,
 
   /* info */
-  LMAP_INFO_SETNAME_CHANGED=1024
+  LMAP_INFO_SETNAME_CHANGED = 1024
 } lives_lmap_error_t;
 
 
