@@ -8,16 +8,17 @@
 #define HAS_LIVES_RTE_WINDOW_H
 
 
-#define RTE_INFO_WIDTH ((int)(350.*widget_opts.scale))
-#define RTE_INFO_HEIGHT ((int)(200.*widget_opts.scale))
+#define RTE_INFO_WIDTH ((int)(550.*widget_opts.scale))
+#define RTE_INFO_HEIGHT ((int)(400.*widget_opts.scale))
 
 void rte_window_set_interactive(boolean interactive);
 
 void on_assign_rte_keys_activate(LiVESMenuItem *, livespointer);
 void on_rte_info_clicked(LiVESButton *, livespointer data);
 void load_default_keymap(void);
+void rtew_combo_set_text(int key, int mode, const char *txt);
 void rtew_set_keych(int key, boolean on);
-void ret_set_key_check_state(void);
+void rtew_set_key_check_state(void);
 void rtew_set_keygr(int key);
 void rtew_set_mode_radio(int key, int mode);
 void rtew_set_grab_button(boolean on);
