@@ -4,16 +4,12 @@
 // released under the GNU GPL 3 or later
 // see file ../COPYING for licensing details
 
-
 // functions for first time startup
 
 #include "main.h"
 #include "interface.h"
 
 
-
-
-
 static boolean prompt_existing_dir(char *dirname, uint64_t freespace, boolean wrtable) {
   char *msg;
   boolean res = FALSE;
@@ -35,9 +31,6 @@ static boolean prompt_existing_dir(char *dirname, uint64_t freespace, boolean wr
 }
 
 
-
-
-
 static boolean prompt_new_dir(char *dirname, uint64_t freespace, boolean wrtable) {
   boolean res = FALSE;
   char *msg;
@@ -73,7 +66,6 @@ void close_file(int current_file, boolean tshoot) {
 }
 
 
-
 boolean do_workdir_query(void) {
   uint64_t freesp;
 
@@ -111,7 +103,6 @@ top:
       continue;
     }
 
-
     if (lives_file_test(dirname, LIVES_FILE_TEST_IS_DIR)) {
       if (is_writeable_dir(dirname)) {
         freesp = get_fs_free(dirname);
@@ -141,7 +132,6 @@ top:
         }
       }
     }
-
     ok = TRUE;
   }
 
@@ -154,7 +144,6 @@ top:
     if (lives_mkdir_with_parents(dirname, capable->umask) == -1) goto top;
   }
 
-
   lives_snprintf(prefs->workdir, PATH_MAX, "%s", dirname);
   lives_snprintf(future_prefs->workdir, PATH_MAX, "%s", prefs->workdir);
 
@@ -168,9 +157,6 @@ top:
 }
 
 
-
-
-
 static void on_init_aplayer_toggled(LiVESToggleButton *tbutton, livespointer user_data) {
   int audp = LIVES_POINTER_TO_INT(user_data);
 
@@ -195,12 +181,9 @@ static void on_init_aplayer_toggled(LiVESToggleButton *tbutton, livespointer use
     set_pref(PREF_AUDIO_PLAYER, AUDIO_PLAYER_MPLAYER2);
     break;
   }
-
 }
 
 
-
-
 boolean do_audio_choice_dialog(short startup_phase) {
   LiVESWidget *dialog, *dialog_vbox, *radiobutton2, *radiobutton3, *radiobutton4, *label;
   LiVESWidget *okbutton, *cancelbutton;
@@ -290,14 +273,11 @@ boolean do_audio_choice_dialog(short startup_phase) {
   lives_container_add(LIVES_CONTAINER(dialog_vbox), label);
   lives_free(msg);
 
-
-
 #ifdef HAVE_PULSE_AUDIO
   hbox = lives_hbox_new(FALSE, 0);
   lives_box_pack_start(LIVES_BOX(dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
-  radiobutton0 = lives_standard_radio_button_new(_("Use _pulse audio player"), TRUE, radiobutton_group, LIVES_BOX(hbox), NULL);
-  radiobutton_group = lives_radio_button_get_group(LIVES_RADIO_BUTTON(radiobutton0));
+  radiobutton0 = lives_standard_radio_button_new(_("Use _pulse audio player"), TRUE, &radiobutton_group, LIVES_BOX(hbox), NULL);
 
   if (prefs->audio_player == -1) prefs->audio_player = AUD_PLAYER_PULSE;
 
@@ -310,16 +290,13 @@ boolean do_audio_choice_dialog(short startup_phase) {
                        LIVES_GUI_CALLBACK(on_init_aplayer_toggled),
                        LIVES_INT_TO_POINTER(AUD_PLAYER_PULSE));
 
-
 #endif
 
-
 #ifdef ENABLE_JACK
   hbox = lives_hbox_new(FALSE, 0);
   lives_box_pack_start(LIVES_BOX(dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
-  radiobutton1 = lives_standard_radio_button_new(_("Use _jack audio player"), TRUE, radiobutton_group, LIVES_BOX(hbox), NULL);
-  radiobutton_group = lives_radio_button_get_group(LIVES_RADIO_BUTTON(radiobutton1));
+  radiobutton1 = lives_standard_radio_button_new(_("Use _jack audio player"), TRUE, &radiobutton_group, LIVES_BOX(hbox), NULL);
 
   if (prefs->audio_player == AUD_PLAYER_JACK || !capable->has_pulse_audio || prefs->audio_player == -1) {
     prefs->audio_player = AUD_PLAYER_JACK;
@@ -331,15 +308,13 @@ boolean do_audio_choice_dialog(short startup_phase) {
                        LIVES_GUI_CALLBACK(on_init_aplayer_toggled),
                        LIVES_INT_TO_POINTER(AUD_PLAYER_JACK));
 
-
 #endif
 
   if (capable->has_sox_play) {
     hbox = lives_hbox_new(FALSE, 0);
     lives_box_pack_start(LIVES_BOX(dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
-    radiobutton2 = lives_standard_radio_button_new(_("Use _sox audio player"), TRUE, radiobutton_group, LIVES_BOX(hbox), NULL);
-    radiobutton_group = lives_radio_button_get_group(LIVES_RADIO_BUTTON(radiobutton2));
+    radiobutton2 = lives_standard_radio_button_new(_("Use _sox audio player"), TRUE, &radiobutton_group, LIVES_BOX(hbox), NULL);
 
     if (prefs->audio_player == -1) prefs->audio_player = AUD_PLAYER_SOX;
 
@@ -351,15 +326,13 @@ boolean do_audio_choice_dialog(short startup_phase) {
     lives_signal_connect(LIVES_GUI_OBJECT(radiobutton2), LIVES_WIDGET_TOGGLED_SIGNAL,
                          LIVES_GUI_CALLBACK(on_init_aplayer_toggled),
                          LIVES_INT_TO_POINTER(AUD_PLAYER_SOX));
-
-
   }
 
   if (capable->has_mplayer) {
     hbox = lives_hbox_new(FALSE, 0);
     lives_box_pack_start(LIVES_BOX(dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
-    radiobutton3 = lives_standard_radio_button_new(_("Use _mplayer audio player"), TRUE, radiobutton_group, LIVES_BOX(hbox), NULL);
+    radiobutton3 = lives_standard_radio_button_new(_("Use _mplayer audio player"), TRUE, &radiobutton_group, LIVES_BOX(hbox), NULL);
 
     if (prefs->audio_player == -1) prefs->audio_player = AUD_PLAYER_MPLAYER;
 
@@ -371,15 +344,13 @@ boolean do_audio_choice_dialog(short startup_phase) {
     lives_signal_connect(LIVES_GUI_OBJECT(radiobutton3), LIVES_WIDGET_TOGGLED_SIGNAL,
                          LIVES_GUI_CALLBACK(on_init_aplayer_toggled),
                          LIVES_INT_TO_POINTER(AUD_PLAYER_MPLAYER));
-
-
   }
 
   if (capable->has_mplayer2) {
     hbox = lives_hbox_new(FALSE, 0);
     lives_box_pack_start(LIVES_BOX(dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
-    radiobutton4 = lives_standard_radio_button_new(_("Use _mplayer2 audio player"), TRUE, radiobutton_group, LIVES_BOX(hbox), NULL);
+    radiobutton4 = lives_standard_radio_button_new(_("Use _mplayer2 audio player"), TRUE, &radiobutton_group, LIVES_BOX(hbox), NULL);
 
     if (prefs->audio_player == -1) prefs->audio_player = AUD_PLAYER_MPLAYER2;
 
@@ -391,8 +362,6 @@ boolean do_audio_choice_dialog(short startup_phase) {
     lives_signal_connect(LIVES_GUI_OBJECT(radiobutton4), LIVES_WIDGET_TOGGLED_SIGNAL,
                          LIVES_GUI_CALLBACK(on_init_aplayer_toggled),
                          LIVES_INT_TO_POINTER(AUD_PLAYER_MPLAYER2));
-
-
   }
 
   cancelbutton = lives_button_new_from_stock(LIVES_STOCK_CANCEL, NULL);
@@ -409,7 +378,6 @@ boolean do_audio_choice_dialog(short startup_phase) {
   lives_widget_grab_default(okbutton);
   lives_widget_grab_focus(okbutton);
 
-
   if (prefs->audio_player == -1) {
     do_no_mplayer_sox_error();
     return LIVES_RESPONSE_CANCEL;
@@ -509,7 +477,6 @@ static LIVES_INLINE char *get_resource(char *fname) {
 }
 
 
-
 boolean do_startup_tests(boolean tshoot) {
   LiVESWidget *dialog;
   LiVESWidget *dialog_vbox;
@@ -559,7 +526,6 @@ boolean do_startup_tests(boolean tshoot) {
     title = lives_strdup(_("Troubleshoot"));
   }
 
-
   dialog = lives_standard_dialog_new(title, FALSE, -1, -1);
 
   accel_group = LIVES_ACCEL_GROUP(lives_accel_group_new());
@@ -588,10 +554,8 @@ boolean do_startup_tests(boolean tshoot) {
   lives_widget_grab_default(okbutton);
   lives_widget_grab_focus(okbutton);
 
-
   lives_widget_set_sensitive(okbutton, FALSE);
 
-
   table = lives_table_new(10, 4, FALSE);
   lives_container_add(LIVES_CONTAINER(dialog_vbox), table);
 
@@ -599,12 +563,10 @@ boolean do_startup_tests(boolean tshoot) {
 
   lives_widget_context_update();
 
-
   // check for sox presence
 
   add_test(table, 0, _("Checking for \"sox\" presence"), TRUE);
 
-
   if (!capable->has_sox_sox) {
     success = fail_test(table, 0, _("You should install sox to be able to use all the audio features in LiVES"));
 
@@ -621,7 +583,6 @@ boolean do_startup_tests(boolean tshoot) {
   get_temp_handle(mainw->first_free_file, TRUE);
 
   if (success) {
-
     info_fd = -1;
 
     lives_rm(cfile->info_file);
@@ -685,10 +646,7 @@ boolean do_startup_tests(boolean tshoot) {
 
         if (fsize == 0) {
           fail_test(table, 1, _("You should install sox_fmt_all or similar"));
-        }
-
-        else pass_test(table, 1);
-
+        } else pass_test(table, 1);
       }
     }
   }
@@ -709,7 +667,6 @@ boolean do_startup_tests(boolean tshoot) {
     return FALSE;
   }
 
-
   // check for mplayer presence
   success2 = TRUE;
 
@@ -751,7 +708,6 @@ boolean do_startup_tests(boolean tshoot) {
     success2 = pass_test(table, 2);
   }
 
-
   // if present
 
   // check if mplayer can decode audio
@@ -792,7 +748,6 @@ boolean do_startup_tests(boolean tshoot) {
 #endif
   }
 
-
   // check if mplayer can decode to png/(alpha)
 
   rname = get_resource("");
@@ -802,7 +757,6 @@ boolean do_startup_tests(boolean tshoot) {
     success4 = FALSE;
   } else success4 = TRUE;
 
-
   lives_free(rname);
 
 #ifdef ALLOW_PNG24
@@ -818,7 +772,6 @@ boolean do_startup_tests(boolean tshoot) {
   // try to open resource vidtest.avi
 
   if (success2 && success4) {
-
     info_fd = -1;
 
     lives_rm(cfile->info_file);
@@ -845,7 +798,6 @@ boolean do_startup_tests(boolean tshoot) {
     }
 
     if (info_fd != -1) {
-
       close(info_fd);
 
       lives_sync();
@@ -926,22 +878,18 @@ boolean do_startup_tests(boolean tshoot) {
     }
   }
 
-
   // TODO - check each enabled decoder plugin in turn
 
-
   // check for convert
 
   add_test(table, 8, _("Checking for \"convert\" presence"), TRUE);
 
-
   if (!capable->has_convert) {
     success = fail_test(table, 8, _("Install imageMagick to be able to use all of the rendered effects"));
   } else {
     success = pass_test(table, 8);
   }
 
-
   close_file(current_file, tshoot);
   mainw->current_file = current_file;
 
@@ -982,16 +930,10 @@ boolean do_startup_tests(boolean tshoot) {
 }
 
 
-
-
-
-
 void do_startup_interface_query(void) {
-
   // prompt for startup ce or startup mt
 
-
-  LiVESWidget *dialog, *dialog_vbox, *radiobutton0, *radiobutton1, *label;
+  LiVESWidget *dialog, *dialog_vbox, *radiobutton, *label;
   LiVESWidget *okbutton;
   LiVESWidget *hbox;
   LiVESSList *radiobutton_group = NULL;
@@ -1001,10 +943,8 @@ void do_startup_interface_query(void) {
   txt2 = lives_strdup(_("\n\nLiVES has two main interfaces and you can start up with either of them.\n"));
   txt3 = lives_strdup(_("\n\nThe default can always be changed later from Preferences.\n"));
 
-
   msg = lives_strdup_printf("%s%s%s", txt1, txt2, txt3);
 
-
   lives_free(txt1);
   lives_free(txt2);
   lives_free(txt3);
@@ -1017,11 +957,9 @@ void do_startup_interface_query(void) {
   lives_container_add(LIVES_CONTAINER(dialog_vbox), label);
   lives_free(msg);
 
-
   hbox = lives_hbox_new(FALSE, 0);
   lives_box_pack_start(LIVES_BOX(dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
-  radiobutton0 = lives_standard_radio_button_new(_("Start in _Clip Edit mode"), TRUE, radiobutton_group, LIVES_BOX(hbox), NULL);
-  radiobutton_group = lives_radio_button_get_group(LIVES_RADIO_BUTTON(radiobutton0));
+  lives_standard_radio_button_new(_("Start in _Clip Edit mode"), TRUE, &radiobutton_group, LIVES_BOX(hbox), NULL);
 
   label = lives_standard_label_new(_("This is the best choice for simple editing tasks and for VJs\n"));
 
@@ -1029,14 +967,14 @@ void do_startup_interface_query(void) {
 
   hbox = lives_hbox_new(FALSE, 0);
   lives_box_pack_start(LIVES_BOX(dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
-  radiobutton1 = lives_standard_radio_button_new(_("Start in _Multitrack mode"), TRUE, radiobutton_group, LIVES_BOX(hbox), NULL);
+  radiobutton = lives_standard_radio_button_new(_("Start in _Multitrack mode"), TRUE, &radiobutton_group, LIVES_BOX(hbox), NULL);
 
   label = lives_standard_label_new(_("This is a better choice for complex editing tasks involving multiple clips.\n"));
 
   lives_box_pack_start(LIVES_BOX(dialog_vbox), label, FALSE, FALSE, widget_opts.packing_height);
 
   if (prefs->startup_interface == STARTUP_MT) {
-    lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton1), TRUE);
+    lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton), TRUE);
   }
 
   okbutton = lives_button_new_from_stock(LIVES_STOCK_GO_FORWARD, _("_Finish"));
@@ -1046,13 +984,11 @@ void do_startup_interface_query(void) {
   lives_widget_grab_default(okbutton);
   lives_widget_grab_focus(okbutton);
 
-
   lives_widget_show_all(dialog);
 
   lives_dialog_run(LIVES_DIALOG(dialog));
 
-
-  if (lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(radiobutton1)))
+  if (lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(radiobutton)))
     future_prefs->startup_interface = prefs->startup_interface = STARTUP_MT;
 
   set_int_pref(PREF_STARTUP_INTERFACE, prefs->startup_interface);
@@ -1060,11 +996,9 @@ void do_startup_interface_query(void) {
   lives_widget_destroy(dialog);
 
   lives_widget_context_update();
-
 }
 
 
-
 void on_troubleshoot_activate(LiVESMenuItem *menuitem, livespointer user_data) {
   do_startup_tests(TRUE);
 }
