@@ -53,7 +53,6 @@ void *streambuf(void *arg) {
 
   uint8_t tmpbuf[STREAM_BUF_SIZE];
 
-
   lstream->bufoffs = 0;
 
   while (buffering) {
@@ -81,7 +80,6 @@ void *streambuf(void *arg) {
 }
 
 
-
 static size_t l2l_rcv_packet(lives_vstream_t *lstream, size_t buflen, void *buf) {
   // take a packet from our stream buffer
   static size_t bufoffs = 0;
@@ -425,7 +423,6 @@ static boolean l2l_parse_packet_header(lives_vstream_t *lstream, int strtype, in
 }
 
 
-
 void lives2lives_read_stream(const char *host, int port) {
   lives_vstream_t *lstream = (lives_vstream_t *)lives_malloc(sizeof(lives_vstream_t));
 
@@ -678,7 +675,6 @@ void lives2lives_read_stream(const char *host, int port) {
 }
 
 
-
 void weed_layer_set_from_lives2lives(weed_plant_t *layer, int clip, lives_vstream_t *lstream) {
   static int64_t last_delta_ticks = 0;
   int64_t currticks;
@@ -796,7 +792,6 @@ void weed_layer_set_from_lives2lives(weed_plant_t *layer, int clip, lives_vstrea
     width = mainw->files[clip]->hsize;
     height = mainw->files[clip]->vsize;
 
-
     if (lstream->hsize != width || lstream->vsize != height) {
       // frame size changed...
       d_print(_("Detected frame size change to %d x %d\n"), lstream->hsize, lstream->vsize);
@@ -988,9 +983,6 @@ void weed_layer_set_from_lives2lives(weed_plant_t *layer, int clip, lives_vstrea
 }
 
 
-
-
-
 //////////////////////////////
 
 // gui bits
@@ -1031,9 +1023,6 @@ void on_send_lives2lives_activate(LiVESMenuItem *menuitem, livespointer user_dat
 }
 
 
-
-
-
 void on_open_lives2lives_activate(LiVESMenuItem *menuitem, livespointer user_data) {
   lives_pandh_w *pandh = create_pandh_dialog(0);
 
@@ -1064,9 +1053,6 @@ void on_open_lives2lives_activate(LiVESMenuItem *menuitem, livespointer user_dat
 }
 
 
-
-
-
 static void pandhw_anyhost_toggled(LiVESToggleButton *tbut, livespointer user_data) {
   lives_pandh_w *pandhw = (lives_pandh_w *)user_data;
 
@@ -1084,7 +1070,6 @@ static void pandhw_anyhost_toggled(LiVESToggleButton *tbut, livespointer user_da
 }
 
 
-
 lives_pandh_w *create_pandh_dialog(int type) {
   // type = 0 lives2lives stream input
 
@@ -1122,9 +1107,8 @@ lives_pandh_w *create_pandh_dialog(int type) {
   lives_box_pack_start(LIVES_BOX(dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
   pandhw->rb_anyhost = lives_standard_radio_button_new((tmp = lives_strdup(_("Accept LiVES streams from _any host")))
-                       , TRUE, radiobutton_group, LIVES_BOX(hbox),
+                       , TRUE, &radiobutton_group, LIVES_BOX(hbox),
                        (tmp2 = lives_strdup(_("Accept incoming LiVES streams from any connected host."))));
-  radiobutton_group = lives_radio_button_get_group(LIVES_RADIO_BUTTON(pandhw->rb_anyhost));
 
   lives_free(tmp);
   lives_free(tmp2);
@@ -1136,9 +1120,8 @@ lives_pandh_w *create_pandh_dialog(int type) {
   hbox = lives_hbox_new(FALSE, 0);
   lives_box_pack_start(LIVES_BOX(dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
-
   lives_standard_radio_button_new((tmp = lives_strdup(_("Accept LiVES streams only from the _specified host:")))
-                                  , TRUE, radiobutton_group, LIVES_BOX(hbox),
+                                  , TRUE, &radiobutton_group, LIVES_BOX(hbox),
                                   (tmp2 = lives_strdup(_("Accept LiVES streams from the specified host only."))));
 
   lives_free(tmp);
@@ -1146,7 +1129,6 @@ lives_pandh_w *create_pandh_dialog(int type) {
 
   ////////////////////////////////////
 
-
   hbox = lives_hbox_new(FALSE, 0);
   lives_box_pack_start(LIVES_BOX(dialog_vbox), hbox, FALSE, FALSE, widget_opts.packing_height);
 
